import { Actions, PolicyStatement, ResourceTypes } from "../shared";
/**
 * Statement provider for service [serverlessrepo](https://docs.aws.amazon.com/IAM/latest/UserGuide/list_awsserverlessapplicationrepository.html).
 *
 * @param sid [SID](https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_sid.html) of the statement
 */
export declare class Serverlessrepo extends PolicyStatement {
    servicePrefix: string;
    protected actionList: Actions;
    protected resourceTypes: ResourceTypes;
    /**
     * Statement provider for service [serverlessrepo](https://docs.aws.amazon.com/IAM/latest/UserGuide/list_awsserverlessapplicationrepository.html).
     *
     * @param sid [SID](https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_sid.html) of the statement
     */
    constructor(sid?: string);
    /**
     * Creates an application, optionally including an AWS SAM file to create the first application version in the same call.
     *
     * Access Level: Write
     */
    createApplication(): this;
    /**
     * Creates an application version.
     *
     * Access Level: Write
     */
    createApplicationVersion(): this;
    /**
     * Creates an AWS CloudFormation ChangeSet for the given application.
     *
     * Access Level: Write
     *
     * Possible conditions:
     * - .ifApplicationType()
     */
    createCloudFormationChangeSet(): this;
    /**
     * Creates an AWS CloudFormation template
     *
     * Access Level: Write
     *
     * Possible conditions:
     * - .ifApplicationType()
     */
    createCloudFormationTemplate(): this;
    /**
     * Deletes the specified application
     *
     * Access Level: Write
     */
    deleteApplication(): this;
    /**
     * Gets the specified application.
     *
     * Access Level: Read
     *
     * Possible conditions:
     * - .ifApplicationType()
     */
    getApplication(): this;
    /**
     * Gets the policy for the specified application.
     *
     * Access Level: Read
     */
    getApplicationPolicy(): this;
    /**
     * Gets the specified AWS CloudFormation template
     *
     * Access Level: Read
     */
    getCloudFormationTemplate(): this;
    /**
     * Retrieves the list of applications nested in the containing application
     *
     * Access Level: List
     *
     * Possible conditions:
     * - .ifApplicationType()
     */
    listApplicationDependencies(): this;
    /**
     * Lists versions for the specified application owned by the requester.
     *
     * Access Level: List
     *
     * Possible conditions:
     * - .ifApplicationType()
     */
    listApplicationVersions(): this;
    /**
     * Lists applications owned by the requester.
     *
     * Access Level: List
     */
    listApplications(): this;
    /**
     * Puts the policy for the specified application.
     *
     * Access Level: Write
     */
    putApplicationPolicy(): this;
    /**
     * Gets all applications authorized for this user
     *
     * Access Level: Read
     *
     * Possible conditions:
     * - .ifApplicationType()
     */
    searchApplications(): this;
    /**
     * Unshares the specified application
     *
     * Access Level: Write
     */
    unshareApplication(): this;
    /**
     * Updates meta-data of the application
     *
     * Access Level: Write
     */
    updateApplication(): this;
    /**
     * Adds a resource of type applications to the statement
     *
     * @param resourceId - Identifier for the resourceId.
     * @param account - Account of the resource; defaults to empty string: all accounts.
     * @param region - Region of the resource; defaults to empty string: all regions.
     * @param partition - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to `aws`.
     */
    onApplications(resourceId: string, account?: string, region?: string, partition?: string): this;
    /**
     * Application type
     *
     * Applies to actions:
     * - .createCloudFormationChangeSet()
     * - .createCloudFormationTemplate()
     * - .getApplication()
     * - .listApplicationDependencies()
     * - .listApplicationVersions()
     * - .searchApplications()
     *
     * @param value The value(s) to check
     * @param operator Works with [string operators](https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String). **Default:** `StringLike`
     */
    ifApplicationType(value: string | string[], operator?: string): this;
}
